--[[
NAME
    map_bar_3d
NOTES
    Plot 3D-bars and text in a plot.
    The example shows how to add objects to the plot, anchoring them properly
    but not allowing rotation and scaling by the plot.
]]

imgw = 600; imgh = 500

-- setup 3D plot

require("plot_3d")
plot = plot_3d.new(imgw, imgh)
plot:scale(.5, .5, .4)
plot:xaxis{range = {130, 170}, tickmarks = {130, 10, 0},
           ticklength = 1.5, label = "Longitude (deg-E)"}
plot:yaxis{range = {-10, 50}, tickmarks = {-10, 10, 0},
           ticklength = 1.5, label = "Latitude (deg-N)"}
plot:zaxis{range = {370, 400}, showlabels = false, showticks = false,
         tickmarks = {375, 5, 0}, ticklength = 1.5, label = "CO<sub>2</sub> (ppm)"}
         
light = zeGrf.new("light")
light:set{position = {500, 500, 500}}
plot:add_static(light)

-- plot CO2 bars

require("bar_3d")

zmin = 370; rotx = -60

x = 140; y = 34; z = 395
x0, y0, z0 = plot.plot:toglobal(imgw, imgh, x, y, zmin)
x1, y1, z1 = plot.plot:toglobal(imgw, imgh, x, y, z)
bar = bar_3d(5, z1-z0, 16)       -- bar height in global scale
bar:set{color = {1, 0, 0, 1}}
plot:add(bar, x, y, zmin)       -- anchor the object at x, y, z

text, font = zeGrf.new("text", "font")       -- un-rotated text label for the bar
text:font(font)
w = text:text("395")
w = -w/2
text:set{layout = {w, 0, 0, w+1, 0, 0, w, 1, 0}}      -- center aligment horizontally
plot:add(text, x, y, z+1)

x = 150; y = 30; z = 376
x0, y0, z0 = plot.plot:toglobal(imgw, imgh, x, y, zmin)
x1, y1, z1 = plot.plot:toglobal(imgw, imgh, x, y, z)
bar = bar_3d(5, z1-z0, 16)
bar:set{color = {1, 1, 0, 1}}
plot:add(bar, x, y, zmin)

x = 160; y = 22; z = 374
x0, y0, z0 = plot.plot:toglobal(imgw, imgh, x, y, zmin)
x1, y1, z1 = plot.plot:toglobal(imgw, imgh, x, y, z)
bar = bar_3d(5, z1-z0, 16)
bar:set{color = {0, 1, 1, 1}}
plot:add(bar, x, y, zmin)

x = 164; y = 7; z = 372
x0, y0, z0 = plot.plot:toglobal(imgw, imgh, x, y, zmin)
x1, y1, z1 = plot.plot:toglobal(imgw, imgh, x, y, z)
bar = bar_3d(5, z1-z0, 16)
bar:set{color = {0, 1, 0, 1}}
plot:add(bar, x, y, zmin)

-- plot coastlines

line, xyz = zeGrf.new("line", "vertex")
line:set{vertex = xyz, type = "lines", color = {0, 0, 1, 1}, solid = 1.5}
plot:add(line)

bio, arr = zeUtl.new("bio", "double")
bio:open("./data/gshhs_l.b")                 -- you must have this file
bio:gshhs("land", 131, 170, -9, 50, arr)

nd = arr:size()
arr:insert(2, 370)

xyz:add(arr)

-- the frame

line, xyz = zeGrf.new("line", "vertex")
line:set{vertex = xyz, type = "strip", solid = 1.5}
plot:add(line)
xyz:add(130, 50, 370)
xyz:add(170, 50, 370)
xyz:add(170, -10, 370)

-- render image

plot:translate(20, 40, 0)
plot:animate()